pub fn apply_step_result(
ctx: &mut ExecutionContext,
result: &StepExecutionResult,
)Expand description
Apply a step execution result to the execution context.
pub fn apply_step_result(
ctx: &mut ExecutionContext,
result: &StepExecutionResult,
)Apply a step execution result to the execution context.